# Available MONAI Label Apps

### Overview

In this folder you will find examples of the **three available paradigms**: Two interactive (DeepGrow, DeepEdit) and one for automated segmentation.


#### DeepGrow

For the DeepGrow paradigm there are two cases: the [deepgrow for left atrium segmentation](./deepgrow_left_atrium) and 
the [deepgrow App](./deepgrow). The latter one is meant for the users that want to build deepgrow-based Apps.

#### DeepEdit

Similar to the deepgrow Apps, you'll find the one generic [deepedit](./deepedit) that researchers can use to build their own deepedit-based app.


#### Automated Segmentation

As the deepgrow and deepedit Apps, researchers can try the non-interactive Apps for [spleen](./segmentation_spleen) and [left atrium](./segmentation_left_atrium) using UNet. There is also the generic segmentation App that researchers can clone to create their own App. 


More examples of these Apps can be found in the [MONAI Label Apps Zoo](https://github.com/diazandr3s/MONAILabel-Apps)




